@@ -47,6 +47,8 @@ class Alarms:
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
 
+        :exampleMetadata: fixture=_generated
+
         Example::
 
             # The code below shows an example of how to instantiate this type.
@@ -102,6 +104,8 @@ class ArbitraryIntervals:
         :param absolute: 
         :param intervals: 
 
+        :exampleMetadata: fixture=_generated
+
         Example::
 
             # The code below shows an example of how to instantiate this type.
@@ -151,20 +155,22 @@ class ArbitraryIntervals:
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-autoscaling-common.CompleteScalingInterval",
     jsii_struct_bases=[],
-    name_mapping={"change": "change", "lower": "lower", "upper": "upper"},
+    name_mapping={"lower": "lower", "upper": "upper", "change": "change"},
 )
 class CompleteScalingInterval:
     def __init__(
         self,
         *,
-        change: typing.Optional[jsii.Number] = None,
         lower: jsii.Number,
         upper: jsii.Number,
+        change: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''
-        :param change: 
         :param lower: 
         :param upper: 
+        :param change: 
+
+        :exampleMetadata: fixture=_generated
 
         Example::
 
@@ -187,11 +193,6 @@ class CompleteScalingInterval:
         if change is not None:
             self._values["change"] = change
 
-    @builtins.property
-    def change(self) -> typing.Optional[jsii.Number]:
-        result = self._values.get("change")
-        return typing.cast(typing.Optional[jsii.Number], result)
-
     @builtins.property
     def lower(self) -> jsii.Number:
         result = self._values.get("lower")
@@ -204,6 +205,11 @@ class CompleteScalingInterval:
         assert result is not None, "Required property 'upper' is missing"
         return typing.cast(jsii.Number, result)
 
+    @builtins.property
+    def change(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("change")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -269,6 +275,8 @@ class ScalingInterval:
         :param lower: The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
         :param upper: The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
 
+        :exampleMetadata: fixture=_generated
+
         Example::
 
             # The code below shows an example of how to instantiate this type.
